﻿#Requires -RunAsAdministrator

[CmdletBinding(SupportsShouldProcess=$true, PositionalBinding=$false)]
Param(
    [Parameter(Mandatory=$false, HelpMessage="Force Installation")]
    [switch]$Force
)
 
#----------------------------------------------------------------------------------------------------------------#
$wc = New-Object System.Net.WebClient;
[Net.ServicePointManager]::Expect100Continue = $true
[Net.ServicePointManager]::SecurityProtocol = "tls12, tls11, tls"
#----------------------------------------------------------------------------------------------------------------#

[bool] $installNetCore8 = $True;
[bool] $installNetCoreRuntime8 = $True;
#----------------------------------------------------------------------------------------------------------------#
$filename = "dotnet_runtime8.exe"
$runtime_exe = "$PSScriptRoot\$filename"
$url = "https://download.visualstudio.microsoft.com/download/pr/7f4d5cbc-4449-4ea5-9578-c467821f251f/b9b19f89d0642bf78f4b612c6a741637/dotnet-runtime-8.0.0-win-x64.exe"
$netCore = Get-Command dotnet -ErrorAction Ignore
if ($netCore.Name -eq "dotnet.exe")
{
    $versions = Get-ChildItem (Get-Command dotnet).Path.Replace('dotnet.exe', 'shared\Microsoft.NETCore.App') -ErrorAction Ignore

    foreach ($version in $versions)
    {
        $matches = [regex]::Match($version.Name, '\A(?<major>[\d]+)\.(?<minor>[\d]+)\.(?<build>[\d]+)')

        foreach ($match in $matches)
        {
            if ($match.Groups['major'].Value -eq 8 -AND $match.Groups['minor'].Value -ge 0 -AND $match.Groups['build'].Value -ge 0)
            {
                Write-Host ".NET 8 Runtime > 8.0.0 is already installed. Skipping step. "
                $installNetCoreRuntime8 = $False
                continue
            }
        }

        if ($installNetCoreRuntime8 -eq $False)
        {
            break
        }
    }
}

if ($installNetCoreRuntime8 -eq $True -or $Force -eq $True)
{
    Write-Host "Path: $runtime_exe";
    $start_time = Get-Date;
    $wc.DownloadFile($url, $runtime_exe);
    write-Output "$filename downloaded";
    write-Output "Time taken: $((Get-Date).Subtract($start_time).Seconds) second(s)";

    Start-Process $runtime_exe -ArgumentList '/install /passive /quiet' -Wait -NoNewWindow -PassThru;

    Remove-Item $runtime_exe;
}

#----------------------------------------------------------------------------------------------------------------#
$filename = "dotnet_aspruntime8.exe"
$dotnet_exe = "$PSScriptRoot\$filename"
$url = "https://download.visualstudio.microsoft.com/download/pr/89d3660b-d344-47c5-a1cd-d8343a3f3779/9f55af82923dab7e3dce912f5c5b9d60/aspnetcore-runtime-8.0.0-win-x64.exe"
$netCore = Get-Command dotnet -ErrorAction Ignore
if ($netCore.Name -eq "dotnet.exe")
{
    $versions = Get-ChildItem (Get-Command dotnet).Path.Replace('dotnet.exe', 'shared\Microsoft.AspNetCore.App') -ErrorAction Ignore

    foreach ($version in $versions)
    {
        $matches = [regex]::Match($version.Name, '\A(?<major>[\d]+)\.(?<minor>[\d]+)\.(?<build>[\d]+)')

        foreach ($match in $matches)
        {
            if ($match.Groups['major'].Value -eq 8 -AND $match.Groups['minor'].Value -ge 0 -AND $match.Groups['build'].Value -ge 0)
            {
                Write-Host "ASP.NET Core > 8.0.0 is already installed. Skipping step. "
                $installNetCore8 = $False
                continue
            }
        }

        if ($installNetCore8 -eq $False)
        {
            break
        }
    }
}

if ($installNetCore8 -eq $True -or $Force -eq $True)
{
    Write-Host "Path: $dotnet_exe";
    $start_time = Get-Date;
    $wc.DownloadFile($url, $dotnet_exe);
    write-Output "$filename downloaded";
    write-Output "Time taken: $((Get-Date).Subtract($start_time).Seconds) second(s)";

    Start-Process $dotnet_exe -ArgumentList '/install /passive /quiet' -Wait -NoNewWindow -PassThru;

    Remove-Item $dotnet_exe;
}
 